import os
import configparser
from pathlib import Path
from werkzeug.middleware.proxy_fix import ProxyFix
from .. import _module_path, logger

default = {"MAIL": {"CRYPT": "SSL/STARTLS"}}

config = configparser.ConfigParser()
config.read_dict(default)
paths = [_module_path, Path.home() / ".config"]
if "FLASCHENGEIST_CONF" in os.environ:
    paths.append(Path(os.environ.get("FLASCHENGEIST_CONF")))
for loc in paths:
    try:
        with (loc / "flaschengeist.cfg").open() as source:
            logger.info("Reading config file from >{}<".format(loc))
            config.read_file(source)
    except IOError:
        pass

# Always enable this builtin plugins!
config.read_dict({"auth": {"enabled": True}, "roles": {"enabled": True}, "users": {"enabled": True}})


def configure_app(app):
    if not config.has_option("FLASCHENGEIST", "SECRET_KEY"):
        logger.warn("No secret key was configured, please configure one for production systems!")
    app.config["SECRET_KEY"] = config.get("FLASCHENGEIST", "SECRET_KEY", fallback="0a657b97ef546da90b2db91862ad4e29")

    app.config["SQLALCHEMY_DATABASE_URI"] = "mysql://{user}:{passwd}@{host}/{database}".format(
        user=config["DATABASE"]["USER"],
        passwd=config["DATABASE"]["PASSWORD"],
        host=config["DATABASE"]["HOST"],
        database=config["DATABASE"]["DATABASE"],
    )
    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False

    if config.has_option("FLASCHENGEIST", "ROOT"):
        logger.debug("Setting application root to >{}<".format(config["FLASCHENGEIST"]["ROOT"]))
        app.config["APPLICATION_ROOT"] = config["FLASCHENGEIST"]["ROOT"]
    if config.getboolean("FLASCHENGEIST", "PROXY", fallback=False):
        logger.debug("Fixing wsgi_app for using behind a proxy server")
        app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)
